@@ -1,6 +1,6 @@
 import logging
 import time
-
+import six
 from rook import config
 from rook.user_warnings import UserWarnings
 from rook.com_ws.token_bucket import TokenBucket
@@ -68,7 +68,10 @@ class Output(object):
             msg.report_id = message_id
 
             if arguments and arguments.size(''):
-                NamespaceSerializer().dump(arguments, msg.arguments)
+                serializer = NamespaceSerializer(config.DumpConfig.STRING_CACHE_USERMESSAGE)
+                serializer.dump(arguments, msg.arguments)
+                for k, v in six.iteritems(serializer.get_string_cache()):
+                    msg.strings_cache[k] = v
 
             error = self._agent_com.add(msg)
             if error:
