@@ -171,7 +171,7 @@ def start(token=None,
             import rook.singleton
             _rook = rook.singleton.singleton_obj
 
-            _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork, _debug, _enable_monitor)
+            _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork, _debug, _enable_monitor, _throw_errors)
         except (RookMissingToken, RookInvalidToken, RookVersionNotSupported, RookOldServers) as e:
             if not _throw_errors:
                 six.print_("[Rookout] Failed to start Rookout:", e, file=sys.stderr)
