@@ -193,12 +193,12 @@ class ImportService(object):
         self._post_import_notifications[location.aug_id] = location
 
         # declaring filenames blacklist for avoiding setting multiple callbacks on the same aug
-        filenames_blacklist = []
+        modules_blacklist = []
         match_found = False
         file_hashes = {}
         with CountingImportLock():
             # Attempt to satisfy location using known modules
-            for module_object in six.itervalues(self._modules):
+            for module_key, module_object in self._modules.items():
                 # Get module details and check if it matches
                 module_filename = self._get_module_path(module_object)
 
@@ -206,18 +206,24 @@ class ImportService(object):
                 if not self._is_valid_module(module_object, module_filename):
                     continue
 
-                if filename == os.path.basename(module_object.__file__):
+                if filename == os.path.basename(module_filename):
                     file_content = self.file_utils.get_safe_file_contents(module_object)
                     if file_content:
                         file_hash = hashlib.sha256(file_content).hexdigest()
                         file_hashes[file_hash] = inspect.getsourcefile(module_object)
 
                 if module_filename:
-                    if module_filename not in filenames_blacklist and self._does_module_match_notification(
-                            module_filename, location, self.external_paths):
-                        match_found = True
-                        filenames_blacklist.append(module_filename)
-                        location.module_found(module_object)
+                    module_identifier = self._get_module_identifier(module_object, module_filename)
+
+                    if module_identifier not in modules_blacklist:
+                        if self._does_module_match_notification(module_filename, location, self.external_paths):
+                            match_found = True
+                            modules_blacklist.append(module_identifier)
+                            location.module_found(module_object)
+                    else:
+                        logger.warn("Found duplicated occurrences of the same module that are matching the aug, "
+                                    "can cause the aug to not be triggered. aug_ig: %s, module_key: %s, module_path: %s"
+                                    % (location.aug_id, module_key, module_filename))
 
         if not match_found:
             if location.file_hash in file_hashes:
@@ -276,26 +282,24 @@ class ImportService(object):
 
     def evaluate_module_list(self):
         try:
-            # Nobody is waiting for notifications
-            if not self._post_import_notifications:
-                return
-
             # No new modules
             if len(self._modules) == len(sys.modules):
                 return
 
             # Get a fresh list
             modules = sys.modules.copy()
-            # self._modules is only replaced (it's immutable - a frozenset), so there's no need to copy it here,
-            # just keep a reference to the current self._modules so we don't start working on a different set
-            # mid-loop
-            old_modules = self._modules
 
-            # For everybody not in the old list, check notifications
-            for module_name, module in six.iteritems(modules):
-                module_filename = self._get_module_path(module)
-                if module_name not in old_modules.keys() and self._is_valid_module(module, module_filename):
-                    self._notify_of_new_module(module, module_filename)
+            if self._post_import_notifications:
+                # self._modules is only replaced (it's immutable - a frozenset), so there's no need to copy it here,
+                # just keep a reference to the current self._modules so we don't start working on a different set
+                # mid-loop
+                old_modules = self._modules
+
+                # For everybody not in the old list, check notifications
+                for module_name, module in six.iteritems(modules):
+                    module_filename = self._get_module_path(module)
+                    if module_name not in old_modules.keys() and self._is_valid_module(module, module_filename):
+                        self._notify_of_new_module(module, module_filename)
 
             # Update the "old" list
             self._modules = modules
@@ -346,6 +350,16 @@ class ImportService(object):
 
         return None
 
+    @staticmethod
+    def _get_module_identifier(module, filename):
+        module_identifier = str(filename)
+        module_identifier += "#" if not hasattr(module, '__name__') else str(module.__name__)
+        module_identifier += "#" if not hasattr(module, '__loader__') else str(type(module.__loader__))
+        module_identifier += "#" if not (hasattr(module, '__loader__') and hasattr(module.__loader__, 'path')) \
+            else str(module.__loader__.path)
+
+        return module_identifier
+
     @staticmethod
     def is_black_listed_path(path):
         for blacklisted_path in _BLACKLISTED_PATHS:
